build_impersonated

Function build_impersonated 

pub fn build_impersonated(typed_tx: FoundryTypedTx) -> FoundryTxEnvelope
Builds a TxEnvelope from UnsignedTx with r=1, s=1 dummy signature.

Used for impersonated accounts, where transactions are accepted without a valid signature. The signature uses r=1, s=1 (not zero) because go-ethereum and other clients reject transactions where r or s are zero with “invalid transaction v, r, s values”.