pub fn build_impersonated(typed_tx: FoundryTypedTx) -> FoundryTxEnvelopeExpand description
Builds a TxEnvelope from UnsignedTx with r=1, s=1 dummy signature.
Used for impersonated accounts, where transactions are accepted without a valid signature. The signature uses r=1, s=1 (not zero) because go-ethereum and other clients reject transactions where r or s are zero with “invalid transaction v, r, s values”.