pub fn build_impersonated(typed_tx: FoundryTypedTx) -> FoundryTxEnvelopeExpand description
Builds a TxEnvelope from UnsignedTx with a zeroed signature.
Used for impersonated accounts, where transactions are accepted without a valid signature.
pub fn build_impersonated(typed_tx: FoundryTypedTx) -> FoundryTxEnvelopeBuilds a TxEnvelope from UnsignedTx with a zeroed signature.
Used for impersonated accounts, where transactions are accepted without a valid signature.